@@ -7,7 +7,9 @@ use lib 'lib';  # just needed because interface lies here
 use MyInterfaces::HelloWorld::HelloWorldSoap;
 
 # I instantiate a interface class.
-my $soap = MyInterfaces::HelloWorld::HelloWorldSoap->new();
+my $soap = MyInterfaces::HelloWorld::HelloWorldSoap->new({
+#	proxy => 'http://localhost:8080/JLearn/WS/sayHello'
+});
 
 # I have to lookup the method and synopsis from the interface's pod
 my $result = $soap->sayHello({
