@@ -1,9 +1,7 @@
 package SOAP::WSDL::XSD::Typelib::Builtin;
 use strict;
 use warnings;
-use Class::Std::Fast::Storable;
-
-use version; our $VERSION = qv('2.00.09');
+use Class::Std::Storable;
 
 use SOAP::WSDL::XSD::Typelib::Builtin::anyType;
 use SOAP::WSDL::XSD::Typelib::Builtin::anySimpleType;
@@ -35,8 +33,6 @@ use SOAP::WSDL::XSD::Typelib::Builtin::long;
 use SOAP::WSDL::XSD::Typelib::Builtin::Name;
 use SOAP::WSDL::XSD::Typelib::Builtin::NCName;
 use SOAP::WSDL::XSD::Typelib::Builtin::negativeInteger;
-use SOAP::WSDL::XSD::Typelib::Builtin::NMTOKEN;
-use SOAP::WSDL::XSD::Typelib::Builtin::NMTOKENS;
 use SOAP::WSDL::XSD::Typelib::Builtin::nonNegativeInteger;
 use SOAP::WSDL::XSD::Typelib::Builtin::nonPositiveInteger;
 use SOAP::WSDL::XSD::Typelib::Builtin::normalizedString;
@@ -64,20 +60,18 @@ SOAP::WSDL::XSD::Typelib::Builtin - Built-in XML Schema datatypes
 
 =head1 DESCRIPTION
 
-The SOAP::WSDL::XSD::Typelib::Builtin hierarchy implements all builtin types
-from the XML schema specification.
+This module implements all builtin Types from the XML schema specification.
 
-All XML schema derived types inherit from
-SOAP::WSDL::XSD::Typelib::Builtin::anyType.
+Objects of a class may be filled with values and serialize correctly.
 
 These basic type classes are most useful when used as element or simpleType
 base classes.
 
-Using SOAP::WSDL::XSD::Typelib::Builtin uses all of the builtin datatype
-classes.
+The datatypes classes themselves are split up into 
+SOAP::WSDL::XSD::Typelib::Builtin::* modules. 
 
-All builtin types feature common behaviour described below in
-L</OVERLOADED OPERATORS>
+Using SOAP::WSDL::XSD::Typelib::Builtin uses all of the builtin datatype 
+classes.
 
 =head1 EXAMPLES
 
@@ -142,7 +136,6 @@ as first item in the base class list.
                      - byte
      - double
      - anyURI
-     - NOTATION
      - string
           - normalizedString
               - language
@@ -152,9 +145,8 @@ as first item in the base class list.
                       - IDREF
                           - IDREFS [list]
                       - ENTITY
-              - token
-                  - NMTOKEN
-                      - NMTOKENS [list]
+              - NMTOKEN
+                  - NMTOKENS [list]
 
 =head1 OVERLOADED OPERATORS
 
@@ -179,36 +171,6 @@ The boolean class returns 0 or 1 in numeric context.
 decimal, float and double (and derived classes) return their value in
 numeric context.
 
-=item * arrayification (@{})
-
-When accessed as a list ref, objects of all classes return a list ref with
-the object itself as single element.
-
-This is most useful for writing loops without additional conversions,
-especially in mini-languages found in templating systems or the like, which
-may not natively support converting to list refs.
-
-Instead of writing something like
-
- my $value = $complexType->get_ELEMENT;
- $value = ref $value eq 'ARRAY' ? $value : [ $value ];
- for (@{ $value }) { ... }
-
-you can just write
-
- for (@{ $complexType->get_ELEMENT }) {...}
-
-Note that complexTypes with undef elements still return undef when accessing
-an undefined element, so when an element may be empty you still have to write
-something like:
-
- my $value = $complexType->get_ELEMENT();
- if (defined $value) {
-     for (@{ $value }) {
-         ...
-     }
- }
-
 =back
 
 =head1 Subclasses
@@ -237,14 +199,9 @@ Returns true/false in boolean context.
 
 Returns 1 / 0 in numeric context.
 
-boolean objects have a special method for deleting their value, because
-calling C<setl_value(undef)> results in the value being set to false.
+=head2 SOAP::WSDL::XSD::Typelib::Builtin::byte 
 
- $obj->delete_value();
-
-=head2 SOAP::WSDL::XSD::Typelib::Builtin::byte
-
-byte integer objects.
+byte integer objects. 
 
 =head2 SOAP::WSDL::XSD::Typelib::Builtin::date
 
@@ -254,33 +211,26 @@ date values are automatically converted into XML date strings during setting:
 
 The time zone is set to the local time zone if not included.
 
-All input variants supported by Date::Parse are supported. You may even pass
-in dateTime strings - the time part will be ignored. Note that
+All input variants supported by Date::Parse are supported. You may even pass 
+in dateTime strings - the time part will be ignored. Note that 
 set_value is around 100 times slower when setting non-XML-time strings
 
-When setting dates before the beginning of the epoch (negative UNIX timestamp),
-you should use the XML date string format for setting dates. The behaviour of
-Date::Parse for dates before the epoch is system dependent.
-
 =head2 SOAP::WSDL::XSD::Typelib::Builtin::dateTime
 
 dateTime values are automatically converted into XML dateTime strings during setting:
 
  YYYY-MM-DDThh:mm:ss.nnnnnnn+zz:zz
 
-The fraction of seconds (nnnnnnn) part is optional. Fractions of seconds may
-be given with arbitrary precision
+The optional nanoseconds parts is excluded in converted values, as it would always be 0.
 
-The fraction of seconds part is excluded in converted values, as it would always be 0.
-
-All input variants supported by Date::Parse are supported. Note that
+All input variants supported by Date::Parse are supported. Note that 
 set_value is around 100 times slower when setting non-XML-time strings
 
 =head2 SOAP::WSDL::XSD::Typelib::Builtin::decimal
 
 decimal is the base of all non-float numbers
 
-=head2 SOAP::WSDL::XSD::Typelib::Builtin::double
+=head2 SOAP::WSDL::XSD::Typelib::Builtin::double 
 
 =head2 SOAP::WSDL::XSD::Typelib::Builtin::duration
 
@@ -332,9 +282,6 @@ Derived by SOAP::WSDL::XSD::Typelib::Builtin::list.
 
 =head2 SOAP::WSDL::XSD::Typelib::Builtin::normalizedString
 
-Tab, newline and carriage return characters are replaced by whitespace in
-set_value.
-
 =head2 SOAP::WSDL::XSD::Typelib::Builtin::NOTATION
 
 =head2 SOAP::WSDL::XSD::Typelib::Builtin::positiveInteger
@@ -345,10 +292,6 @@ set_value.
 
 =head2 SOAP::WSDL::XSD::Typelib::Builtin::string
 
-String values are XML-escaped on serialization.
-
-The following characters are escaped: <, >, &
-
 =head2 SOAP::WSDL::XSD::Typelib::Builtin::time
 
 time values are automatically converted into XML time strings during setting:
@@ -356,12 +299,12 @@ time values are automatically converted into XML time strings during setting:
  hh:mm:ss.nnnnnnn+zz:zz
  hh:mm:ss+zz:zz
 
-The time zone is set to the local time zone if not included. The optional
+The time zone is set to the local time zone if not included. The optional 
 nanoseconds part is not included in converted values, as it would always be 0.
 
-All input variants supported by Date::Parse are supported. You may even pass
-in dateTime strings - the date part will be ignored. Note that
-set_value is around 100 times slower when setting non-XML-time strings.
+All input variants supported by Date::Parse are supported. You may even pass 
+in dateTime strings - the date part will be ignored. Note that 
+set_value is around 100 times slower when setting non-XML-time strings
 
 =head2 SOAP::WSDL::XSD::Typelib::Builtin::token
 
@@ -379,10 +322,10 @@ set_value is around 100 times slower when setting non-XML-time strings.
 
 =item * set_value
 
-In contrast to Class::Std-generated mutators (setters), set_value does
+In contrast to Class::Std-generated mutators (setters), set_value does 
 not return the last value.
 
-This is for speed reasons: SOAP::WSDL never needs to know the last value
+This is for speed reasons: SOAP::WSDL never needs to know the last value 
 when calling set_calue, but calls it over and over again...
 
 =back
@@ -393,7 +336,7 @@ when calling set_calue, but calls it over and over again...
 
 =item * Thread safety
 
-SOAP::WSDL::XSD::Typelib::Builtin uses Class::Std::Fast::Storable which uses
+SOAP::WSDL::XSD::Typelib::Builtin uses Class::Std::Storable which uses
 Class::Std. Class::Std is not thread safe, so
 SOAP::WSDL::XSD::Typelib::Builtin is neither.
 
@@ -409,11 +352,11 @@ Replace whitespace by @ in e-mail address.
 
  Martin Kutter E<gt>martin.kutter fen-net.deE<lt>
 
-=head1 LICENSE AND COPYRIGHT
+=head1 Licenxe
 
 Copyright 2004-2007 Martin Kutter.
 
-This file is part of SOAP-WSDL. You may distribute/modify it under the
+This library is free software, you may distribute/modify it under the
 same terms as perl itself
 
 =cut
