@@ -1,8 +1,8 @@
+#!/usr/bin/perl
 package SOAP::WSDL::XSD::Typelib::Element;
-use strict; use warnings;
-use Class::Std::Fast::Storable constructor => 'none';
-
-use version; our $VERSION = qv('2.00.09');
+use strict;
+use Class::Std::Storable;
+use Data::Dumper;
 
 my %NAME;
 my %NILLABLE;
@@ -10,8 +10,6 @@ my %REF;
 my %MIN_OCCURS;
 my %MAX_OCCURS;
 
-# TODO replace by generated methods?
-#
 # Class data - remember, we're the base class for a class factory or for
 # generated code...
 # use BLOCK: for scoping
@@ -24,61 +22,42 @@ BLOCK: {
         _maxOccurs => \%MAX_OCCURS,
     );
 
-    # create getters / setters for all elements' class data
     no strict qw(refs);
     while (my ($name, $value) = each %method_lookup ) {
         *{ "__set$name" } = sub {
-            @_ or die "Cannot call __set$name without parameter";
             my $class = ref $_[0] || $_[0];
             $value->{ $class } = $_[1];
         };
         *{ "__get$name" } = sub {
-            @_ or die "Cannot call __set$name as function";
             my $class = ref $_[0] || $_[0];
             return $value->{ $class };
         };
     }
 };
 
-
-# use $_[0] and $_[1] for speed.
-
 sub start_tag {
-    # my ($self, $opt, $value) = @_;
-    my $ending = ($_[1]->{ empty }) ? '/>' : '>';
+    my ($self, $opt, $value) = @_;
+    my $class = ref $self;
+    my $ending = '>';
     my @attr_from = ();
-
-    if ($_[1]->{ nil }) {
-        return q{} if not $NILLABLE{ ref $_[0] };
-        push @attr_from, q{ xsi:nil="true"};
+    my $name = $opt->{ name } || $NAME{$class};
+    $ending = '/>' if ($opt->{ empty });
+    
+    if ($opt->{qualified}) {
+        push @attr_from, 'xmlns="' . $self->get_xmlns . '"';
+    }
+    if ($opt->{ nil }) {
+        return q{} if not $NILLABLE{ $class };
+        push @attr_from, 'xsi:nil="true"';
         $ending = '/>';
     }
-    if (delete $_[1]->{qualified}) {
-        push @attr_from, q{ xmlns="} . $_[0]->get_xmlns() . q{"};
-    }
-    push @attr_from, $_[0]->serialize_attr();
-
-    # do we need to check for name ? Element ref="" should have it's own
-    # start_tag. If we don't need to check, we can speed things up
-    return join q{}, "<$_[1]->{ name }" , @attr_from , $ending if $_[1]->{ name };
-    return join q{}, "<$NAME{ ref $_[0]}" , @attr_from , $ending;
+    return join q{ }, "<$name" , @attr_from , $ending;
 }
 
-# use $_[0] and $_[1] for speed.
-#
-# read it as:
-#
-# my ($self, $opt)  = @_;
-# my $class = ref $self;
-# return "</$opt->{name}>" if $opt->{name};
-# return "</"$NAME{$class}>";
-#
-# do we need to check for name ? Element ref="" should have it's own
-# end_tag. If we don't need to check, we can speed things up by defining
-# end tag with () prototype - perl will inline it for us if we do...
 sub end_tag {
-    return "</$_[1]->{name}>" if $_[1]->{name};
-    return "</$NAME{ ref $_[0] }>";
+    my ($class, $opt) = (ref $_[0], $_[1]);
+    my $name = $opt->{ name } || $NAME{$class};
+    return "</$name>";
 }
 
 1;
@@ -98,7 +77,7 @@ This example creates a class for this XML schema definition:
 
  package MyElement;
  use strict;
- use Class::Std::Fast::Storable constructor => 'none';
+ use Class::Std::Storable;
  use base (
     'SOAP::WSDL::XSD::Typelib::Element',
     'SOAP::WSDL::XSD::Typelib::Builtin::string',
@@ -113,10 +92,10 @@ This example creates a class for this XML schema definition:
 Now we create this XML schema definition type class:
 
  <element name="MyElement2" ref="tns:MyElement"/>
-
+ 
  package MyElement2;
  use strict;
- use Class::Std::Fast::Storable constructor => 'none';
+ use Class::Std::Storable;
  use base (
     'SOAP::WSDL::XSD::Typelib::Element',
     'MyElement'
@@ -125,10 +104,10 @@ Now we create this XML schema definition type class:
  __PACKAGE__->__set_name('MyElementName');
  __PACKAGE__->__set_nillable(0);
  __PACKAGE__->__set_ref(1);
-
+ 
 =head1 NOTES
 
-=over
+=over 
 
 =item * type="Foo"
 
@@ -136,14 +115,14 @@ Implemented via inheritance.
 
 =item * ref="Foo"
 
-Implemented via inheritance, too. Calling
+Implemented via inheritance, too. Calling 
 
-__PACKAGE__->__set_ref(1) is highly encouraged, though it has no
-effect yet - it will probably be needed for serialization to XML
+__PACKAGE__->__set_ref(1) is highly encouraged, though it has no 
+effect yet - it will probably be needed for serialization to XML 
 Schema definitions some day.
 
 =back
-
+ 
 =head1 BUGS AND LIMITATIONS
 
 =over
@@ -164,24 +143,4 @@ namespace combination (Default for SOAP::WSDL::Envelope).
 
 =back
 
-=head1 LICENSE AND COPYRIGHT
-
-Copyright 2004-2007 Martin Kutter.
-
-This file is part of SOAP-WSDL. You may distribute/modify it under the same
-terms as perl itself
-
-=head1 AUTHOR
-
-Martin Kutter E<lt>martin.kutter fen-net.deE<gt>
-
-=head1 REPOSITORY INFORMATION
-
- $Rev: 805 $
- $LastChangedBy: kutterma $
- $Id: Element.pm 805 2009-02-23 21:12:24Z kutterma $
- $HeadURL: https://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/trunk/lib/SOAP/WSDL/XSD/Typelib/Element.pm $
-
 =cut
-
-
